Exception: Pgoutput::Client::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/pgoutput/client/errors.rb

Overview

Base error class for all pgoutput-client failures.

Rescue this class when callers want to handle any error raised by the transport layer without also rescuing unrelated Ruby or PostgreSQL driver exceptions.