Module: Pgoutput::Client
- Defined in:
- lib/pgoutput/client.rb,
lib/pgoutput/client/lsn.rb,
lib/pgoutput/client/errors.rb,
lib/pgoutput/client/stream.rb,
lib/pgoutput/client/version.rb,
lib/pgoutput/client/commands.rb,
lib/pgoutput/client/feedback.rb,
lib/pgoutput/client/keepalive.rb,
lib/pgoutput/client/xlog_data.rb,
lib/pgoutput/client/connection.rb,
lib/pgoutput/client/configuration.rb
Overview
Namespace for PostgreSQL logical replication transport support.
‘Pgoutput::Client` is the replication transport layer of the CDC Ecosystem. It is responsible for connecting to PostgreSQL in replication mode, creating or consuming replication slots, issuing `START_REPLICATION`, reading CopyData messages, and sending standby feedback.
This namespace intentionally does not parse pgoutput plugin payloads into table-level changes. Raw plugin bytes are yielded to downstream protocol and type layers such as ‘pgoutput-parser` and `pgoutput-decoder`.
Defined Under Namespace
Modules: Commands, LSN Classes: Configuration, ConfigurationError, Connection, ConnectionError, Error, Feedback, FeedbackData, Keepalive, KeepaliveData, ProtocolError, ReplicationXLogData, Runner, Stream, XLogData
Constant Summary collapse
- VERSION =
Current pgoutput-client gem version.
"0.1.0"